<?php
/**
 * Implements an optional custom header for Catch Box Pro.
 * See http://codex.wordpress.org/Custom_Headers
 *
 * @package WordPress
 * @subpackage Catch+Box_Pro
 * @since Catch Box Pro 1.0
 */

if ( ! function_exists( 'catchbox_custom_header_setup' ) ) :
/**
 * Sets up the WordPress core custom header arguments and settings.
 *
 * @uses add_theme_support() to register support for 3.4 and up.
 * @uses catchbox_header_style() to style front-end.
 * @uses catchbox_admin_header_style() to style wp-admin form.
 * @uses catchbox_admin_header_image() to add custom markup to wp-admin form.
 *
 * @since Catch Box Pro 1.0
 */
function catchbox_custom_header_setup() {
	
	// For WordPress 3.4+
	if ( function_exists( 'get_custom_header') ) {
		$args = array(
			// Text color and image (empty to use none).
			'default-text-color'     => '000',
			'default-image'          => '',
	
			// Set height and width, with a maximum value for the width.
			'height'                 => 125,
			'width'                  => 300,
			'max-width'              => 1000,
	
			// Support flexible height and width.
			'flex-height'            => true,
			'flex-width'             => true,
	
			// Random image rotation off by default.
			'random-default'         => false,
	
			// Callbacks for styling the header and the admin preview.
			'wp-head-callback'       => 'catchbox_header_style',
			'admin-head-callback'    => 'catchbox_admin_header_style',
			'admin-preview-callback' => 'catchbox_admin_header_image',
		);
			
		add_theme_support( 'custom-header', $args );
		
	} 
}
endif; // catchbox_custom_header_setup

add_action( 'after_setup_theme', 'catchbox_custom_header_setup' );

if ( ! function_exists( 'catchbox_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @since Catch Box 1.0
 */
function catchbox_header_style() {

	$text_color = get_header_textcolor();
	
	// If no custom options for text are set, let's bail.
	if ( $text_color == HEADER_TEXTCOLOR )
		return;

	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == $text_color ) :
	?>
		#site-title,
		#site-description {
			position: absolute !important;
			clip: rect(1px 1px 1px 1px); /* IE6, IE7 */
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php 
	
		// If the user has set a custom color for the text use that
		else :
	?>
		#site-title a,
		#site-description {
			color: #<?php echo get_header_textcolor(); ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // catchbox_header_style

if ( ! function_exists( 'catchbox_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * @since Catch Box 1.0
 */
function catchbox_admin_header_style() {
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		border: none;
	}
	#headimg h1,
	#desc {
		font-family: "Helvetica Neue", Arial, Helvetica, "Nimbus Sans L", sans-serif;
	}
	#headimg h1 {
		margin: 0;
	}
	#headimg h1 a {
		font-size: 32px;
		line-height: 36px;
		text-decoration: none;
	}
	#desc {
		font-size: 14px;
		line-height: 23px;
		padding: 0 0 3em;
	}
	<?php
		// If the user has set a custom color for the text use that
		if ( get_header_textcolor() != HEADER_TEXTCOLOR ) :
	?>
		#site-title a,
		#site-description {
			color: #<?php echo get_header_textcolor(); ?>;
		}
	<?php endif; ?>

	#headimg img {
		height: auto;
		max-width: 100%;
	}
	</style>
<?php
}
endif; // catchbox_admin_header_style

if ( ! function_exists( 'catchbox_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * @since Catch Box 1.0
 */
function catchbox_admin_header_image() { ?>
	<div id="headimg">
		<?php
		$color = get_header_textcolor();
		$image = get_header_image();
		if ( $color && $color != 'blank' )
			$style = ' style="color:#' . $color . '"';
		else
			$style = ' style="display:none"';
		?>
		
		<h1><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
		<?php if ( $image ) : ?>
			<img src="<?php echo esc_url( $image ); ?>" alt="" />
		<?php endif; ?>
	</div>
<?php }
endif; // catchbox_admin_header_image


if ( ! function_exists( 'catchbox_header_image' ) ) :
/**
 * Template for Header Image
 *
 * To override this in a child theme
 * simply create your own catchbox_header_image(), and that function will be used instead.
 *
 * @since Catch Box Pro 2.2.1
 */
function catchbox_header_image() {
	
	// Check to see if the header image has been removed
	global $_wp_default_headers;
	$header_image = get_header_image();
	if ( ! empty( $header_image ) ) : ?>
    
    	<div id="site-logo">
        	<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home">
                <img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" />
            </a>
      	</div>
        
	<?php endif; // end check for removed header image 	
}
endif;


if ( ! function_exists( 'catchbox_header_details' ) ) :
/**
 * Template for Header Details
 *
 * To override this in a child theme
 * simply create your own catchbox_header_details(), and that function will be used instead.
 *
 * @since Catch Box Pro 2.2.1
 */
function catchbox_header_details() { 

	// Check to see if the header image has been removed
	global $_wp_default_headers;
	$header_image = get_header_image();
	if ( ! empty( $header_image ) ) : 
     	echo '<div id="hgroup" class="site-details with-logo">';
	else :
    	echo '<div id="hgroup" class="site-details">';     
	endif; // end check for removed header image  ?>
 
   		<h1 id="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
       	<h2 id="site-description"><?php bloginfo( 'description' ); ?></h2>
   	</div><!-- #hgroup --> 

<?php
}
endif;


if ( ! function_exists( 'catchbox_headerdetails' ) ) :
/**
 * Header Details including Site Logo, Title and Description
 *
 * @Hooked in catchbox_headercontent
 * @since Catch Box 1.2.1
 */
function catchbox_headerdetails() {
	
	// Getting data from Theme Options
	global $catchbox_options_settings;
	$options = $catchbox_options_settings;
	$sitedetails = $options['site_title_above'];
	
	echo '<div class="logo-wrap clearfix">';
	
	if ( $sitedetails == '0' ) {
		echo catchbox_header_image();
		echo catchbox_header_details();
	} else {
		echo catchbox_header_details();
		echo catchbox_header_image();
	}
	
	echo '</div><!-- .logo-wrap -->';

} 
endif; //catchbox_headerdetails

add_action( 'catchbox_headercontent', 'catchbox_headerdetails', 15 ); 


if ( ! function_exists( 'catchbox_header_search' ) ) :
/**
 * Header Search Box
 *
 * @since Catch Box 1.2.1
 */
function catchbox_header_search() { ?>
	<aside class="widget widget_search" id="header-search">
		<?php get_search_form(); ?>
	</aside>
    <?php
}        
endif; //catchbox_header_search


if ( ! function_exists( 'catchbox_header_menu' ) ) :
/**
 * Header Menu
 *
 * @since Catch Box 1.2.1
 */
function catchbox_header_menu() { ?>
	<nav id="access" role="navigation">
		<h3 class="assistive-text"><?php _e( 'Primary menu', 'catchbox' ); ?></h3>
		<?php /*  Allow screen readers / text browsers to skip the navigation menu and get right to the good stuff. */ ?>
		<div class="skip-link"><a class="assistive-text" href="#content" title="<?php esc_attr_e( 'Skip to primary content', 'catchbox' ); ?>"><?php _e( 'Skip to primary content', 'catchbox' ); ?></a></div>
		<div class="skip-link"><a class="assistive-text" href="#secondary" title="<?php esc_attr_e( 'Skip to secondary content', 'catchbox' ); ?>"><?php _e( 'Skip to secondary content', 'catchbox' ); ?></a></div>
		<?php /* Our navigation menu.  If one isn't filled out, wp_nav_menu falls back to wp_page_menu. The menu assiged to the primary position is the one used. If none is assigned, the menu with the lowest ID is used. */ ?>
	
		<?php
			if ( has_nav_menu( 'primary', 'catchbox' ) ) { 
				$args = array(
					'theme_location'    => 'primary',
					'container_class' 	=> 'menu-header-container', 
					'items_wrap'        => '<ul class="menu">%3$s</ul>' 
				);
				wp_nav_menu( $args );
			}
			else {
				echo '<div class="menu-header-container">';
					wp_page_menu( array( 'menu_class'  => 'menu' ) );
				echo '</div>';
			} ?> 		
			   
		</nav><!-- #access -->
		
	<?php if ( has_nav_menu( 'secondary', 'catchbox' ) ) {
		// Check is footer menu is enable or not
		$options = get_option( 'catchbox_options' );
		if ( !empty ($options ['enable_menus'] ) ) :
			$menuclass = "mobile-enable";
		else :
			$menuclass = "mobile-disable";
		endif;
		?>
		<nav id="access-secondary" class="<?php echo $menuclass; ?>"  role="navigation">
			<h3 class="assistive-text"><?php _e( 'Secondary menu', 'catchbox' ); ?></h3>
				<?php /*  Allow screen readers / text browsers to skip the navigation menu and get right to the good stuff. */ ?>
				<div class="skip-link"><a class="assistive-text" href="#content" title="<?php esc_attr_e( 'Skip to primary content', 'catchbox' ); ?>"><?php _e( 'Skip to primary content', 'catchbox' ); ?></a></div>
				<div class="skip-link"><a class="assistive-text" href="#secondary" title="<?php esc_attr_e( 'Skip to secondary content', 'catchbox' ); ?>"><?php _e( 'Skip to secondary content', 'catchbox' ); ?></a></div>
			<?php wp_nav_menu( array( 'theme_location'  => 'secondary', 'container_class' => 'menu-secondary-container' ) );  ?>
		</nav>
	<?php }
} 
endif; //catchbox_header_menu

// Load Header Menu in  catchbox_after_headercontent hook 
add_action( 'catchbox_after_headercontent', 'catchbox_header_menu', 10 ); 


/**
 * Header Top Sidebar
 *
 * @Hooked in catchbox_headercontent
 * @since Catch Box 1.2.1
 */
add_action( 'catchbox_headercontent', 'catchbox_header_topsidebar', 10 ); 
function catchbox_header_topsidebar() {
	get_sidebar( 'headertop' ); 
}  

/**
 * Header Right Sidebar
 *
 * @Hooked in catchbox_headercontent
 * @since Catch Box 1.2.1
 */
add_action( 'catchbox_headercontent', 'catchbox_header_rightpsidebar', 20 ); 
function catchbox_header_rightpsidebar() {
	get_sidebar( 'headerright' ); 
}  